# This file is auto-generated by tools/build_api.py
# Do not edit manually.

# Structs
from pyritex.netlink.socket import NetlinkSocket
from pyritex.netlink.message import RouteMessage
from pyritex.netlink.message import NetlinkHeader
from pyritex.netlink.message import RtMsg

# Constants
from pyritex.netlink.consts import AF_INET
from pyritex.netlink.consts import AF_NETLINK
from pyritex.netlink.consts import AF_BRIDGE
from pyritex.netlink.consts import IFLA_IFNAME
from pyritex.netlink.consts import IFF_LOWER_UP
from pyritex.netlink.consts import IFF_DORMANT
from pyritex.netlink.consts import IFLA_WIRELESS
from pyritex.netlink.consts import IFLA_OPERSTATE
from pyritex.netlink.consts import IFLA_LINKMODE
from pyritex.netlink.consts import IF_OPER_DORMANT
from pyritex.netlink.consts import IF_OPER_UP
from pyritex.netlink.consts import RTNLGRP_LINK
from pyritex.netlink.consts import SOL_NETLINK
from pyritex.netlink.consts import NLMSG_MIN_TYPE
from pyritex.netlink.consts import GENL_NAMSIZ
from pyritex.netlink.consts import GENL_MIN_ID
from pyritex.netlink.consts import GENL_MAX_ID
from pyritex.netlink.consts import GENL_ADMIN_PERM
from pyritex.netlink.consts import GENL_CMD_CAP_DO
from pyritex.netlink.consts import GENL_CMD_CAP_DUMP
from pyritex.netlink.consts import GENL_CMD_CAP_HASPOL
from pyritex.netlink.consts import GENL_ID_GENERATE
from pyritex.netlink.consts import GENL_ID_CTRL
from pyritex.netlink.consts import CTRL_CMD_UNSPEC
from pyritex.netlink.consts import CTRL_CMD_NEWFAMILY
from pyritex.netlink.consts import CTRL_CMD_DELFAMILY
from pyritex.netlink.consts import CTRL_CMD_GETFAMILY
from pyritex.netlink.consts import CTRL_CMD_NEWOPS
from pyritex.netlink.consts import CTRL_CMD_DELOPS
from pyritex.netlink.consts import CTRL_CMD_GETOPS
from pyritex.netlink.consts import CTRL_CMD_NEWMCAST_GRP
from pyritex.netlink.consts import CTRL_CMD_DELMCAST_GRP
from pyritex.netlink.consts import CTRL_CMD_GETMCAST_GRP
from pyritex.netlink.consts import CTRL_CMD_GETPOLICY
from pyritex.netlink.consts import CTRL_ATTR_UNSPEC
from pyritex.netlink.consts import CTRL_ATTR_FAMILY_ID
from pyritex.netlink.consts import CTRL_ATTR_FAMILY_NAME
from pyritex.netlink.consts import CTRL_ATTR_VERSION
from pyritex.netlink.consts import CTRL_ATTR_HDRSIZE
from pyritex.netlink.consts import CTRL_ATTR_MAXATTR
from pyritex.netlink.consts import CTRL_ATTR_OPS
from pyritex.netlink.consts import CTRL_ATTR_MCAST_GROUPS
from pyritex.netlink.consts import CTRL_ATTR_POLICY
from pyritex.netlink.consts import CTRL_ATTR_OP_POLICY
from pyritex.netlink.consts import CTRL_ATTR_OP
from pyritex.netlink.consts import CTRL_ATTR_OP_UNSPEC
from pyritex.netlink.consts import CTRL_ATTR_OP_ID
from pyritex.netlink.consts import CTRL_ATTR_OP_FLAGS
from pyritex.netlink.consts import CTRL_ATTR_MCAST_GRP_UNSPEC
from pyritex.netlink.consts import CTRL_ATTR_MCAST_GRP_NAME
from pyritex.netlink.consts import CTRL_ATTR_MCAST_GRP_ID
from pyritex.netlink.consts import NL_ATTR_TYPE_INVALID
from pyritex.netlink.consts import NL_ATTR_TYPE_FLAG
from pyritex.netlink.consts import NL_ATTR_TYPE_U8
from pyritex.netlink.consts import NL_ATTR_TYPE_U16
from pyritex.netlink.consts import NL_ATTR_TYPE_U32
from pyritex.netlink.consts import NL_ATTR_TYPE_U64
from pyritex.netlink.consts import NL_ATTR_TYPE_S8
from pyritex.netlink.consts import NL_ATTR_TYPE_S16
from pyritex.netlink.consts import NL_ATTR_TYPE_S32
from pyritex.netlink.consts import NL_ATTR_TYPE_S64
from pyritex.netlink.consts import NL_ATTR_TYPE_BINARY
from pyritex.netlink.consts import NL_ATTR_TYPE_STRING
from pyritex.netlink.consts import NL_ATTR_TYPE_NUL_STRING
from pyritex.netlink.consts import NL_ATTR_TYPE_NESTED
from pyritex.netlink.consts import NL_ATTR_TYPE_NESTED_ARRAY
from pyritex.netlink.consts import NL_ATTR_TYPE_BITFIELD32
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_UNSPEC
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_TYPE
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_MIN_VALUE_S
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_MAX_VALUE_S
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_MIN_VALUE_U
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_MAX_VALUE_U
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_MIN_LENGTH
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_MAX_LENGTH
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_POLICY_IDX
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_POLICY_MAXTYPE
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_BITFIELD32_MASK
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_PAD
from pyritex.netlink.consts import NL_POLICY_TYPE_ATTR_MASK
from pyritex.netlink.consts import NETLINK_ROUTE
from pyritex.netlink.consts import NETLINK_UNUSED
from pyritex.netlink.consts import NETLINK_USERSOCK
from pyritex.netlink.consts import NETLINK_FIREWALL
from pyritex.netlink.consts import NETLINK_SOCK_DIAG
from pyritex.netlink.consts import NETLINK_NFLOG
from pyritex.netlink.consts import NETLINK_XFRM
from pyritex.netlink.consts import NETLINK_SELINUX
from pyritex.netlink.consts import NETLINK_ISCSI
from pyritex.netlink.consts import NETLINK_AUDIT
from pyritex.netlink.consts import NETLINK_FIB_LOOKUP
from pyritex.netlink.consts import NETLINK_CONNECTOR
from pyritex.netlink.consts import NETLINK_NETFILTER
from pyritex.netlink.consts import NETLINK_IP6_FW
from pyritex.netlink.consts import NETLINK_DNRTMSG
from pyritex.netlink.consts import NETLINK_KOBJECT_UEVENT
from pyritex.netlink.consts import NETLINK_GENERIC
from pyritex.netlink.consts import NETLINK_SCSITRANSPORT
from pyritex.netlink.consts import NLA_F_NESTED
from pyritex.netlink.consts import NLA_F_NET_BYTEORDER
from pyritex.netlink.consts import NLM_F_REQUEST
from pyritex.netlink.consts import NLM_F_MULTI
from pyritex.netlink.consts import NLM_F_ACK
from pyritex.netlink.consts import NLM_F_ECHO
from pyritex.netlink.consts import NLM_F_DUMP_INTR
from pyritex.netlink.consts import NLM_F_DUMP_FILTERED
from pyritex.netlink.consts import NLM_F_ROOT
from pyritex.netlink.consts import NLM_F_MATCH
from pyritex.netlink.consts import NLM_F_ATOMIC
from pyritex.netlink.consts import NLM_F_DUMP
from pyritex.netlink.consts import NLM_F_REPLACE
from pyritex.netlink.consts import NLM_F_EXCL
from pyritex.netlink.consts import NLM_F_CREATE
from pyritex.netlink.consts import NLM_F_APPEND
from pyritex.netlink.consts import NLM_F_CAPPED
from pyritex.netlink.consts import NLM_F_ACK_TLVS
from pyritex.netlink.consts import NLMSG_NOOP
from pyritex.netlink.consts import NLMSG_ERROR
from pyritex.netlink.consts import NLMSG_DONE
from pyritex.netlink.consts import NLMSG_OVERRUN
from pyritex.netlink.consts import NLMSG_CONTROL
from pyritex.netlink.consts import NLMSG_TRANSPORT
from pyritex.netlink.consts import NLMSG_MIN_TYPE
from pyritex.netlink.consts import NLMSG_MAX_LEN
from pyritex.netlink.consts import NLMSG_HDR_FORMAT
from pyritex.netlink.consts import NLMSG_HDR_SIZE
from pyritex.netlink.consts import SOL_NETLINK
from pyritex.netlink.consts import NETLINK_ADD_MEMBERSHIP
from pyritex.netlink.consts import NETLINK_DROP_MEMBERSHIP
from pyritex.netlink.consts import NETLINK_PKTINFO
from pyritex.netlink.consts import NETLINK_BROADCAST_ERROR
from pyritex.netlink.consts import NETLINK_NO_ENOBUFS
from pyritex.netlink.consts import NETLINK_RX_RING
from pyritex.netlink.consts import NETLINK_TX_RING
from pyritex.netlink.consts import NETLINK_LISTEN_ALL_NSID
from pyritex.netlink.consts import NETLINK_EXT_ACK
from pyritex.netlink.consts import NETLINK_GET_STRICT_CHK
from pyritex.netlink.consts import NLMSG_ALIGNTO
from pyritex.netlink.rtnl.consts import RTM_BASE
from pyritex.netlink.rtnl.consts import RTM_NEWLINK
from pyritex.netlink.rtnl.consts import RTM_DELLINK
from pyritex.netlink.rtnl.consts import RTM_GETLINK
from pyritex.netlink.rtnl.consts import RTM_SETLINK
from pyritex.netlink.rtnl.consts import RTM_NEWADDR
from pyritex.netlink.rtnl.consts import RTM_DELADDR
from pyritex.netlink.rtnl.consts import RTM_GETADDR
from pyritex.netlink.rtnl.consts import RTM_NEWROUTE
from pyritex.netlink.rtnl.consts import RTM_DELROUTE
from pyritex.netlink.rtnl.consts import RTM_GETROUTE
from pyritex.netlink.rtnl.consts import RTM_NEWNEIGH
from pyritex.netlink.rtnl.consts import RTM_DELNEIGH
from pyritex.netlink.rtnl.consts import RTM_GETNEIGH
from pyritex.netlink.rtnl.consts import RTM_NEWRULE
from pyritex.netlink.rtnl.consts import RTM_DELRULE
from pyritex.netlink.rtnl.consts import RTM_GETRULE
from pyritex.netlink.rtnl.consts import RTM_NEWQDISC
from pyritex.netlink.rtnl.consts import RTM_DELQDISC
from pyritex.netlink.rtnl.consts import RTM_GETQDISC
from pyritex.netlink.rtnl.consts import RTM_NEWTCLASS
from pyritex.netlink.rtnl.consts import RTM_DELTCLASS
from pyritex.netlink.rtnl.consts import RTM_GETTCLASS
from pyritex.netlink.rtnl.consts import RTM_NEWTFILTER
from pyritex.netlink.rtnl.consts import RTM_DELTFILTER
from pyritex.netlink.rtnl.consts import RTM_GETTFILTER
from pyritex.netlink.rtnl.consts import RTM_NEWACTION
from pyritex.netlink.rtnl.consts import RTM_DELACTION
from pyritex.netlink.rtnl.consts import RTM_GETACTION
from pyritex.netlink.rtnl.consts import RTM_NEWPREFIX
from pyritex.netlink.rtnl.consts import RTM_GETMULTICAST
from pyritex.netlink.rtnl.consts import RTM_GETANYCAST
from pyritex.netlink.rtnl.consts import RTM_NEWNEIGHTBL
from pyritex.netlink.rtnl.consts import RTM_GETNEIGHTBL
from pyritex.netlink.rtnl.consts import RTM_SETNEIGHTBL
from pyritex.netlink.rtnl.consts import RTM_NEWNDUSEROPT
from pyritex.netlink.rtnl.consts import RTM_NEWADDRLABEL
from pyritex.netlink.rtnl.consts import RTM_DELADDRLABEL
from pyritex.netlink.rtnl.consts import RTM_GETADDRLABEL
from pyritex.netlink.rtnl.consts import RTM_GETDCB
from pyritex.netlink.rtnl.consts import RTM_SETDCB
from pyritex.netlink.rtnl.consts import __RTM_MAX
from pyritex.netlink.rtnl.consts import RTM_MAX
from pyritex.netlink.rtnl.consts import RTM_NR_MSGTYPES
from pyritex.netlink.rtnl.consts import RTM_NR_FAMILIES
from pyritex.netlink.rtnl.consts import RTA_ALIGNTO
from pyritex.netlink.rtnl.consts import RTN_UNSPEC
from pyritex.netlink.rtnl.consts import RTN_UNICAST
from pyritex.netlink.rtnl.consts import RTN_LOCAL
from pyritex.netlink.rtnl.consts import RTN_BROADCAST
from pyritex.netlink.rtnl.consts import RTN_ANYCAST
from pyritex.netlink.rtnl.consts import RTN_MULTICAST
from pyritex.netlink.rtnl.consts import RTN_BLACKHOLE
from pyritex.netlink.rtnl.consts import RTN_UNREACHABLE
from pyritex.netlink.rtnl.consts import RTN_PROHIBIT
from pyritex.netlink.rtnl.consts import RTN_THROW
from pyritex.netlink.rtnl.consts import RTN_NAT
from pyritex.netlink.rtnl.consts import RTN_XRESOLVE
from pyritex.netlink.rtnl.consts import __RTN_MAX
from pyritex.netlink.rtnl.consts import RTN_MAX
from pyritex.netlink.rtnl.consts import RTPROT_UNSPEC
from pyritex.netlink.rtnl.consts import RTPROT_REDIRECT
from pyritex.netlink.rtnl.consts import RTPROT_KERNEL
from pyritex.netlink.rtnl.consts import RTPROT_BOOT
from pyritex.netlink.rtnl.consts import RTPROT_STATIC
from pyritex.netlink.rtnl.consts import RTPROT_GATED
from pyritex.netlink.rtnl.consts import RTPROT_RA
from pyritex.netlink.rtnl.consts import RTPROT_MRT
from pyritex.netlink.rtnl.consts import RTPROT_ZEBRA
from pyritex.netlink.rtnl.consts import RTPROT_BIRD
from pyritex.netlink.rtnl.consts import RTPROT_DNROUTED
from pyritex.netlink.rtnl.consts import RTPROT_XORP
from pyritex.netlink.rtnl.consts import RTPROT_NTK
from pyritex.netlink.rtnl.consts import RTPROT_DHCP
from pyritex.netlink.rtnl.consts import RT_SCOPE_UNIVERSE
from pyritex.netlink.rtnl.consts import RT_SCOPE_SITE
from pyritex.netlink.rtnl.consts import RT_SCOPE_LINK
from pyritex.netlink.rtnl.consts import RT_SCOPE_HOST
from pyritex.netlink.rtnl.consts import RT_SCOPE_NOWHERE
from pyritex.netlink.rtnl.consts import RTM_F_NOTIFY
from pyritex.netlink.rtnl.consts import RTM_F_CLONED
from pyritex.netlink.rtnl.consts import RTM_F_EQUALIZE
from pyritex.netlink.rtnl.consts import RTM_F_PREFIX
from pyritex.netlink.rtnl.consts import RT_TABLE_UNSPEC
from pyritex.netlink.rtnl.consts import RT_TABLE_COMPAT
from pyritex.netlink.rtnl.consts import RT_TABLE_DEFAULT
from pyritex.netlink.rtnl.consts import RT_TABLE_MAIN
from pyritex.netlink.rtnl.consts import RT_TABLE_LOCAL
from pyritex.netlink.rtnl.consts import RT_TABLE_MAX
from pyritex.netlink.rtnl.consts import RTA_UNSPEC
from pyritex.netlink.rtnl.consts import RTA_DST
from pyritex.netlink.rtnl.consts import RTA_SRC
from pyritex.netlink.rtnl.consts import RTA_IIF
from pyritex.netlink.rtnl.consts import RTA_OIF
from pyritex.netlink.rtnl.consts import RTA_GATEWAY
from pyritex.netlink.rtnl.consts import RTA_PRIORITY
from pyritex.netlink.rtnl.consts import RTA_PREFSRC
from pyritex.netlink.rtnl.consts import RTA_METRICS
from pyritex.netlink.rtnl.consts import RTA_MULTIPATH
from pyritex.netlink.rtnl.consts import RTA_PROTOINFO
from pyritex.netlink.rtnl.consts import RTA_FLOW
from pyritex.netlink.rtnl.consts import RTA_CACHEINFO
from pyritex.netlink.rtnl.consts import RTA_SESSION
from pyritex.netlink.rtnl.consts import RTA_MP_ALGO
from pyritex.netlink.rtnl.consts import RTA_TABLE
from pyritex.netlink.rtnl.consts import __RTA_MAX
from pyritex.netlink.rtnl.consts import RTA_MAX
from pyritex.netlink.rtnl.consts import RTNH_F_DEAD
from pyritex.netlink.rtnl.consts import RTNH_F_PERVASIVE
from pyritex.netlink.rtnl.consts import RTNH_F_ONLINK
from pyritex.netlink.rtnl.consts import RTNH_ALIGNTO
from pyritex.netlink.rtnl.consts import RTAX_UNSPEC
from pyritex.netlink.rtnl.consts import RTAX_LOCK
from pyritex.netlink.rtnl.consts import RTAX_MTU
from pyritex.netlink.rtnl.consts import RTAX_WINDOW
from pyritex.netlink.rtnl.consts import RTAX_RTT
from pyritex.netlink.rtnl.consts import RTAX_RTTVAR
from pyritex.netlink.rtnl.consts import RTAX_SSTHRESH
from pyritex.netlink.rtnl.consts import RTAX_CWND
from pyritex.netlink.rtnl.consts import RTAX_ADVMSS
from pyritex.netlink.rtnl.consts import RTAX_REORDERING
from pyritex.netlink.rtnl.consts import RTAX_HOPLIMIT
from pyritex.netlink.rtnl.consts import RTAX_INITCWND
from pyritex.netlink.rtnl.consts import RTAX_FEATURES
from pyritex.netlink.rtnl.consts import RTAX_RTO_MIN
from pyritex.netlink.rtnl.consts import __RTAX_MAX
from pyritex.netlink.rtnl.consts import RTAX_MAX
from pyritex.netlink.rtnl.consts import RTAX_FEATURE_ECN
from pyritex.netlink.rtnl.consts import RTAX_FEATURE_SACK
from pyritex.netlink.rtnl.consts import RTAX_FEATURE_TIMESTAMP
from pyritex.netlink.rtnl.consts import RTAX_FEATURE_ALLFRAG
from pyritex.netlink.rtnl.consts import PREFIX_UNSPEC
from pyritex.netlink.rtnl.consts import PREFIX_ADDRESS
from pyritex.netlink.rtnl.consts import PREFIX_CACHEINFO
from pyritex.netlink.rtnl.consts import __PREFIX_MAX
from pyritex.netlink.rtnl.consts import PREFIX_MAX
from pyritex.netlink.rtnl.consts import TCA_UNSPEC
from pyritex.netlink.rtnl.consts import TCA_KIND
from pyritex.netlink.rtnl.consts import TCA_OPTIONS
from pyritex.netlink.rtnl.consts import TCA_STATS
from pyritex.netlink.rtnl.consts import TCA_XSTATS
from pyritex.netlink.rtnl.consts import TCA_RATE
from pyritex.netlink.rtnl.consts import TCA_FCNT
from pyritex.netlink.rtnl.consts import TCA_STATS2
from pyritex.netlink.rtnl.consts import TCA_STAB
from pyritex.netlink.rtnl.consts import __TCA_MAX
from pyritex.netlink.rtnl.consts import TCA_MAX
from pyritex.netlink.rtnl.consts import NDUSEROPT_UNSPEC
from pyritex.netlink.rtnl.consts import NDUSEROPT_SRCADDR
from pyritex.netlink.rtnl.consts import __NDUSEROPT_MAX
from pyritex.netlink.rtnl.consts import NDUSEROPT_MAX
from pyritex.netlink.rtnl.consts import RTMGRP_LINK
from pyritex.netlink.rtnl.consts import RTMGRP_NOTIFY
from pyritex.netlink.rtnl.consts import RTMGRP_NEIGH
from pyritex.netlink.rtnl.consts import RTMGRP_TC
from pyritex.netlink.rtnl.consts import RTMGRP_IPV4_IFADDR
from pyritex.netlink.rtnl.consts import RTMGRP_IPV4_MROUTE
from pyritex.netlink.rtnl.consts import RTMGRP_IPV4_ROUTE
from pyritex.netlink.rtnl.consts import RTMGRP_IPV4_RULE
from pyritex.netlink.rtnl.consts import RTMGRP_IPV6_IFADDR
from pyritex.netlink.rtnl.consts import RTMGRP_IPV6_MROUTE
from pyritex.netlink.rtnl.consts import RTMGRP_IPV6_ROUTE
from pyritex.netlink.rtnl.consts import RTMGRP_IPV6_IFINFO
from pyritex.netlink.rtnl.consts import RTMGRP_IPV6_PREFIX
from pyritex.netlink.rtnl.consts import RTNLGRP_NONE
from pyritex.netlink.rtnl.consts import RTNLGRP_LINK
from pyritex.netlink.rtnl.consts import RTNLGRP_NOTIFY
from pyritex.netlink.rtnl.consts import RTNLGRP_NEIGH
from pyritex.netlink.rtnl.consts import RTNLGRP_TC
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV4_IFADDR
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV4_MROUTE
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV4_ROUTE
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV4_RULE
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV6_IFADDR
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV6_MROUTE
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV6_ROUTE
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV6_IFINFO
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV6_PREFIX
from pyritex.netlink.rtnl.consts import RTNLGRP_IPV6_RULE
from pyritex.netlink.rtnl.consts import RTNLGRP_ND_USEROPT
from pyritex.netlink.rtnl.consts import RTNLGRP_PHONET_IFADDR
from pyritex.netlink.rtnl.consts import RTNLGRP_PHONET_ROUTE
from pyritex.netlink.rtnl.consts import __RTNLGRP_MAX
from pyritex.netlink.rtnl.consts import RTNLGRP_MAX

__all__ = [
    "NetlinkSocket",
    "RouteMessage",
    "NetlinkHeader",
    "RtMsg",
    "AF_INET",
    "AF_NETLINK",
    "AF_BRIDGE",
    "IFLA_IFNAME",
    "IFF_LOWER_UP",
    "IFF_DORMANT",
    "IFLA_WIRELESS",
    "IFLA_OPERSTATE",
    "IFLA_LINKMODE",
    "IF_OPER_DORMANT",
    "IF_OPER_UP",
    "RTNLGRP_LINK",
    "SOL_NETLINK",
    "NLMSG_MIN_TYPE",
    "GENL_NAMSIZ",
    "GENL_MIN_ID",
    "GENL_MAX_ID",
    "GENL_ADMIN_PERM",
    "GENL_CMD_CAP_DO",
    "GENL_CMD_CAP_DUMP",
    "GENL_CMD_CAP_HASPOL",
    "GENL_ID_GENERATE",
    "GENL_ID_CTRL",
    "CTRL_CMD_UNSPEC",
    "CTRL_CMD_NEWFAMILY",
    "CTRL_CMD_DELFAMILY",
    "CTRL_CMD_GETFAMILY",
    "CTRL_CMD_NEWOPS",
    "CTRL_CMD_DELOPS",
    "CTRL_CMD_GETOPS",
    "CTRL_CMD_NEWMCAST_GRP",
    "CTRL_CMD_DELMCAST_GRP",
    "CTRL_CMD_GETMCAST_GRP",
    "CTRL_CMD_GETPOLICY",
    "CTRL_ATTR_UNSPEC",
    "CTRL_ATTR_FAMILY_ID",
    "CTRL_ATTR_FAMILY_NAME",
    "CTRL_ATTR_VERSION",
    "CTRL_ATTR_HDRSIZE",
    "CTRL_ATTR_MAXATTR",
    "CTRL_ATTR_OPS",
    "CTRL_ATTR_MCAST_GROUPS",
    "CTRL_ATTR_POLICY",
    "CTRL_ATTR_OP_POLICY",
    "CTRL_ATTR_OP",
    "CTRL_ATTR_OP_UNSPEC",
    "CTRL_ATTR_OP_ID",
    "CTRL_ATTR_OP_FLAGS",
    "CTRL_ATTR_MCAST_GRP_UNSPEC",
    "CTRL_ATTR_MCAST_GRP_NAME",
    "CTRL_ATTR_MCAST_GRP_ID",
    "NL_ATTR_TYPE_INVALID",
    "NL_ATTR_TYPE_FLAG",
    "NL_ATTR_TYPE_U8",
    "NL_ATTR_TYPE_U16",
    "NL_ATTR_TYPE_U32",
    "NL_ATTR_TYPE_U64",
    "NL_ATTR_TYPE_S8",
    "NL_ATTR_TYPE_S16",
    "NL_ATTR_TYPE_S32",
    "NL_ATTR_TYPE_S64",
    "NL_ATTR_TYPE_BINARY",
    "NL_ATTR_TYPE_STRING",
    "NL_ATTR_TYPE_NUL_STRING",
    "NL_ATTR_TYPE_NESTED",
    "NL_ATTR_TYPE_NESTED_ARRAY",
    "NL_ATTR_TYPE_BITFIELD32",
    "NL_POLICY_TYPE_ATTR_UNSPEC",
    "NL_POLICY_TYPE_ATTR_TYPE",
    "NL_POLICY_TYPE_ATTR_MIN_VALUE_S",
    "NL_POLICY_TYPE_ATTR_MAX_VALUE_S",
    "NL_POLICY_TYPE_ATTR_MIN_VALUE_U",
    "NL_POLICY_TYPE_ATTR_MAX_VALUE_U",
    "NL_POLICY_TYPE_ATTR_MIN_LENGTH",
    "NL_POLICY_TYPE_ATTR_MAX_LENGTH",
    "NL_POLICY_TYPE_ATTR_POLICY_IDX",
    "NL_POLICY_TYPE_ATTR_POLICY_MAXTYPE",
    "NL_POLICY_TYPE_ATTR_BITFIELD32_MASK",
    "NL_POLICY_TYPE_ATTR_PAD",
    "NL_POLICY_TYPE_ATTR_MASK",
    "NETLINK_ROUTE",
    "NETLINK_UNUSED",
    "NETLINK_USERSOCK",
    "NETLINK_FIREWALL",
    "NETLINK_SOCK_DIAG",
    "NETLINK_NFLOG",
    "NETLINK_XFRM",
    "NETLINK_SELINUX",
    "NETLINK_ISCSI",
    "NETLINK_AUDIT",
    "NETLINK_FIB_LOOKUP",
    "NETLINK_CONNECTOR",
    "NETLINK_NETFILTER",
    "NETLINK_IP6_FW",
    "NETLINK_DNRTMSG",
    "NETLINK_KOBJECT_UEVENT",
    "NETLINK_GENERIC",
    "NETLINK_SCSITRANSPORT",
    "NLA_F_NESTED",
    "NLA_F_NET_BYTEORDER",
    "NLM_F_REQUEST",
    "NLM_F_MULTI",
    "NLM_F_ACK",
    "NLM_F_ECHO",
    "NLM_F_DUMP_INTR",
    "NLM_F_DUMP_FILTERED",
    "NLM_F_ROOT",
    "NLM_F_MATCH",
    "NLM_F_ATOMIC",
    "NLM_F_DUMP",
    "NLM_F_REPLACE",
    "NLM_F_EXCL",
    "NLM_F_CREATE",
    "NLM_F_APPEND",
    "NLM_F_CAPPED",
    "NLM_F_ACK_TLVS",
    "NLMSG_NOOP",
    "NLMSG_ERROR",
    "NLMSG_DONE",
    "NLMSG_OVERRUN",
    "NLMSG_CONTROL",
    "NLMSG_TRANSPORT",
    "NLMSG_MIN_TYPE",
    "NLMSG_MAX_LEN",
    "NLMSG_HDR_FORMAT",
    "NLMSG_HDR_SIZE",
    "SOL_NETLINK",
    "NETLINK_ADD_MEMBERSHIP",
    "NETLINK_DROP_MEMBERSHIP",
    "NETLINK_PKTINFO",
    "NETLINK_BROADCAST_ERROR",
    "NETLINK_NO_ENOBUFS",
    "NETLINK_RX_RING",
    "NETLINK_TX_RING",
    "NETLINK_LISTEN_ALL_NSID",
    "NETLINK_EXT_ACK",
    "NETLINK_GET_STRICT_CHK",
    "NLMSG_ALIGNTO",
    "RTM_BASE",
    "RTM_NEWLINK",
    "RTM_DELLINK",
    "RTM_GETLINK",
    "RTM_SETLINK",
    "RTM_NEWADDR",
    "RTM_DELADDR",
    "RTM_GETADDR",
    "RTM_NEWROUTE",
    "RTM_DELROUTE",
    "RTM_GETROUTE",
    "RTM_NEWNEIGH",
    "RTM_DELNEIGH",
    "RTM_GETNEIGH",
    "RTM_NEWRULE",
    "RTM_DELRULE",
    "RTM_GETRULE",
    "RTM_NEWQDISC",
    "RTM_DELQDISC",
    "RTM_GETQDISC",
    "RTM_NEWTCLASS",
    "RTM_DELTCLASS",
    "RTM_GETTCLASS",
    "RTM_NEWTFILTER",
    "RTM_DELTFILTER",
    "RTM_GETTFILTER",
    "RTM_NEWACTION",
    "RTM_DELACTION",
    "RTM_GETACTION",
    "RTM_NEWPREFIX",
    "RTM_GETMULTICAST",
    "RTM_GETANYCAST",
    "RTM_NEWNEIGHTBL",
    "RTM_GETNEIGHTBL",
    "RTM_SETNEIGHTBL",
    "RTM_NEWNDUSEROPT",
    "RTM_NEWADDRLABEL",
    "RTM_DELADDRLABEL",
    "RTM_GETADDRLABEL",
    "RTM_GETDCB",
    "RTM_SETDCB",
    "__RTM_MAX",
    "RTM_MAX",
    "RTM_NR_MSGTYPES",
    "RTM_NR_FAMILIES",
    "RTA_ALIGNTO",
    "RTN_UNSPEC",
    "RTN_UNICAST",
    "RTN_LOCAL",
    "RTN_BROADCAST",
    "RTN_ANYCAST",
    "RTN_MULTICAST",
    "RTN_BLACKHOLE",
    "RTN_UNREACHABLE",
    "RTN_PROHIBIT",
    "RTN_THROW",
    "RTN_NAT",
    "RTN_XRESOLVE",
    "__RTN_MAX",
    "RTN_MAX",
    "RTPROT_UNSPEC",
    "RTPROT_REDIRECT",
    "RTPROT_KERNEL",
    "RTPROT_BOOT",
    "RTPROT_STATIC",
    "RTPROT_GATED",
    "RTPROT_RA",
    "RTPROT_MRT",
    "RTPROT_ZEBRA",
    "RTPROT_BIRD",
    "RTPROT_DNROUTED",
    "RTPROT_XORP",
    "RTPROT_NTK",
    "RTPROT_DHCP",
    "RT_SCOPE_UNIVERSE",
    "RT_SCOPE_SITE",
    "RT_SCOPE_LINK",
    "RT_SCOPE_HOST",
    "RT_SCOPE_NOWHERE",
    "RTM_F_NOTIFY",
    "RTM_F_CLONED",
    "RTM_F_EQUALIZE",
    "RTM_F_PREFIX",
    "RT_TABLE_UNSPEC",
    "RT_TABLE_COMPAT",
    "RT_TABLE_DEFAULT",
    "RT_TABLE_MAIN",
    "RT_TABLE_LOCAL",
    "RT_TABLE_MAX",
    "RTA_UNSPEC",
    "RTA_DST",
    "RTA_SRC",
    "RTA_IIF",
    "RTA_OIF",
    "RTA_GATEWAY",
    "RTA_PRIORITY",
    "RTA_PREFSRC",
    "RTA_METRICS",
    "RTA_MULTIPATH",
    "RTA_PROTOINFO",
    "RTA_FLOW",
    "RTA_CACHEINFO",
    "RTA_SESSION",
    "RTA_MP_ALGO",
    "RTA_TABLE",
    "__RTA_MAX",
    "RTA_MAX",
    "RTNH_F_DEAD",
    "RTNH_F_PERVASIVE",
    "RTNH_F_ONLINK",
    "RTNH_ALIGNTO",
    "RTAX_UNSPEC",
    "RTAX_LOCK",
    "RTAX_MTU",
    "RTAX_WINDOW",
    "RTAX_RTT",
    "RTAX_RTTVAR",
    "RTAX_SSTHRESH",
    "RTAX_CWND",
    "RTAX_ADVMSS",
    "RTAX_REORDERING",
    "RTAX_HOPLIMIT",
    "RTAX_INITCWND",
    "RTAX_FEATURES",
    "RTAX_RTO_MIN",
    "__RTAX_MAX",
    "RTAX_MAX",
    "RTAX_FEATURE_ECN",
    "RTAX_FEATURE_SACK",
    "RTAX_FEATURE_TIMESTAMP",
    "RTAX_FEATURE_ALLFRAG",
    "PREFIX_UNSPEC",
    "PREFIX_ADDRESS",
    "PREFIX_CACHEINFO",
    "__PREFIX_MAX",
    "PREFIX_MAX",
    "TCA_UNSPEC",
    "TCA_KIND",
    "TCA_OPTIONS",
    "TCA_STATS",
    "TCA_XSTATS",
    "TCA_RATE",
    "TCA_FCNT",
    "TCA_STATS2",
    "TCA_STAB",
    "__TCA_MAX",
    "TCA_MAX",
    "NDUSEROPT_UNSPEC",
    "NDUSEROPT_SRCADDR",
    "__NDUSEROPT_MAX",
    "NDUSEROPT_MAX",
    "RTMGRP_LINK",
    "RTMGRP_NOTIFY",
    "RTMGRP_NEIGH",
    "RTMGRP_TC",
    "RTMGRP_IPV4_IFADDR",
    "RTMGRP_IPV4_MROUTE",
    "RTMGRP_IPV4_ROUTE",
    "RTMGRP_IPV4_RULE",
    "RTMGRP_IPV6_IFADDR",
    "RTMGRP_IPV6_MROUTE",
    "RTMGRP_IPV6_ROUTE",
    "RTMGRP_IPV6_IFINFO",
    "RTMGRP_IPV6_PREFIX",
    "RTNLGRP_NONE",
    "RTNLGRP_LINK",
    "RTNLGRP_NOTIFY",
    "RTNLGRP_NEIGH",
    "RTNLGRP_TC",
    "RTNLGRP_IPV4_IFADDR",
    "RTNLGRP_IPV4_MROUTE",
    "RTNLGRP_IPV4_ROUTE",
    "RTNLGRP_IPV4_RULE",
    "RTNLGRP_IPV6_IFADDR",
    "RTNLGRP_IPV6_MROUTE",
    "RTNLGRP_IPV6_ROUTE",
    "RTNLGRP_IPV6_IFINFO",
    "RTNLGRP_IPV6_PREFIX",
    "RTNLGRP_IPV6_RULE",
    "RTNLGRP_ND_USEROPT",
    "RTNLGRP_PHONET_IFADDR",
    "RTNLGRP_PHONET_ROUTE",
    "__RTNLGRP_MAX",
    "RTNLGRP_MAX",
]
